function minCurrent = knauerpumpobjreadmincurrent(serialObject, pumpHeadSize)
% KNAUERPUMPOBJREADMINCURRENT returns the minimum current of Knauer pumps
% minCurrent = knauerpumpobjreadmincurrent(serialObject, pumpHeadSize)
% returns the minimum current of Knauer pumps connected to a valid serial
% object, as numbers.  If no pump head size is supplied, it will try and
% retrieve it, but if one is supplied, then will retrieve the minimum
% current set for that pump head size.

% checks the number of arguments
error(nargchk(1, 2, nargin))

% if a pump head size was supplied...
if nargin >= 2
    
    % check the input
    if ~isvalidknauerpumpheadsize(pumpHeadSize)
        
        % complain
        error('Must supply a valid pump head size - 10 or 50 [mL].')
    end

else
    
    % fetch it
    pumpHeadSize = knauerpumpobjreadpumpheadsizefast(serialObject);
end

% forms and writes command, adding the pump head size to the command
% because there are different values for this
minCurrent = knauerpumpobjcomm(serialObject, 'read', sprintf('IMIN%d?', pumpHeadSize));